'' =================================================================================================
''
''   File....... jm_timer_demo.spin
''   Purpose....
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (C) 2015 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started....
''   Updated.... 26 JUL 2015
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                           ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                          ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                    ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                                ' ticks in 1us


con { io pins }
  
  RX1   = 31                                                     ' programming / terminal
  TX1   = 30

  SDA   = 29                                                     ' eeprom / i2c
  SCL   = 28

  LED27 = 27                                                     ' pab LEDs
  LED26 = 26

  
con

  T1_MILLIS  = 100

  T2_MILLIS1 = 333                                               ' T2 combines == 1000ms
  T2_MILLIS0 = 667
   

obj

' main                                                           ' * master Spin cog
  io   : "jm_io_basic"                                           '   essential io control
  time : "jm_time"                                               '   timing and delays
  term : "jm_fullduplexserial"                                   ' * serial io for terminal

' * Uses cog when loaded


var

  long  t1                                                       ' timer sync points
  long  t2

  long  seconds


pub main 

  setup

  longfill(@t1, time.millis, 2)

  repeat
    process_1
    process_2
    

pub process_1

  if ((time.millis - t1) => T1_MILLIS)
    io.toggle(LED26)
    t1 += T1_MILLIS


pub process_2

  if (ina[LED27] == 0)
    if ((time.millis - t2) => T2_MILLIS0)
      io.high(LED27)
      ++seconds
      t2 += T2_MILLIS0

  else
    if ((time.millis - t2) => T2_MILLIS1)
      io.low(LED27)
      t2 += T2_MILLIS1
      

pub setup

'' Setup IO and objects for application

  io.start($0000, $0000)                                         ' clear all pins

  time.start                                                     ' setup timing/delays for clock speed


dat { license }

{{

  Copyright (C) 2015 Jon McPhalen

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}